@@ -21,7 +21,6 @@ PREREQ_PKGS="wget make git python-pip python-dev python-mysqldb libxml2-dev libx
 SERVICE_SRV_NAME="murano-dashboard"
 GIT_CLONE_DIR=`echo $SERVICE_CONTENT_DIRECTORY | sed -e "s/$SERVICE_SRV_NAME//"`
 HORIZON_CONFIGS="/opt/stack/horizon/openstack_dashboard/settings.py,/usr/share/openstack-dashboard/openstack_dashboard/settings.py"
-NON_PIP_PACKAGES_BASE_DIR=$SERVICE_CONTENT_DIRECTORY/libs
 
 # Functions
 # Logger function
@@ -98,7 +97,12 @@ HORIZON_CONFIG['exceptions']['recoverable'] = EXTENDED_RECOVERABLE_EXCEPTIONS
 HORIZON_CONFIG['exceptions']['not_found'] = EXTENDED_NOT_FOUND_EXCEPTIONS
 HORIZON_CONFIG['exceptions']['unauthorized'] = EXTENDED_UNAUTHORIZED_EXCEPTIONS
 HORIZON_CONFIG['customization_module'] = 'muranodashboard.panel.overrides'
-INSTALLED_APPS += ('muranodashboard','djblets','djblets.datagrid','djblets.util','floppyforms',)
+INSTALLED_APPS += ('muranodashboard','floppyforms',)
+MIDDLEWARE_CLASSES += ('muranodashboard.middleware.ExceptionMiddleware',)
+LOGGING['formatters'] = {'verbose': {'format': '[%(asctime)s] [%(levelname)s] [pid=%(process)d] %(message)s'}}
+LOGGING['handlers']['file'] = {'level': 'DEBUG', 'formatter': 'verbose', 'class': 'logging.FileHandler', 'filename': '/var/log/murano-dashboard.log'}
+LOGGING['loggers']['muranodashboard'] = {'handlers': ['file'], 'level': 'DEBUG'}
+LOGGING['loggers']['muranoclient'] = {'handlers': ['file'], 'level': 'ERROR'}
 #if murano-api set up with ssl uncomment next strings
 #MURANO_API_INSECURE = True
 #END_MURANO_DASHBOARD
@@ -187,17 +191,6 @@ CLONE_FROM_GIT=$1
 			log "pip install \"$TRBL_FILE\" FAILS, exiting!!!"
 			exit 1
 		fi
-		# NON PIP PACKAGES INSTALL START
-		for pkg in djblets; do
-		    PKG_DIR=$NON_PIP_PACKAGES_BASE_DIR/$pkg
-	            cd $PKG_DIR
-	            python setup.py install
-	            if [ $? -ne 0 ]; then
-        		log "\"$PKG_DIR/setup.py\" python setup FAILS, exiting!"
-			exit 1
-        	    fi
-		done
-	        # NON PIP PACKAGES INSTALL END
 		else
 		log "$MRN_CND_SPY not found!"
 	fi
@@ -257,6 +250,7 @@ postinst()
 {
         rebuildstatic
 	sleep 2
+	chown www-data:www-data /var/log/murano-dashboard.log
 	service apache2 restart
 }
 # Command line args'
